;//////////////////////////////////////////////////////////////////////////////
;
;  27_05_2015	14:30		
;
;  1WIRE (DALLAS DS1990)
;  v3.0
;  t85
;
;*******************************************************************************
;   
.EQU	DS1wire_PORT 	= PORTB		; Dallas 1-Wire bus
.EQU	DS1wire_DIR 	= DDRB
.EQU	DS1wire_PIN 	= PINB
.EQU	DS1wire 	= 1
;
.EQU	SYSCLK		= 8000		; 8000 Hz (T=271.267 ns)                                    
;
.EQU	DSReadROM	= 0x33
;
;
.def	Reg_r16		= R23
.def	Reg_r19		= R22
.def	Reg_r20		= R21
;
;*******************************************************************************
;****** T O U C H R E S E T
;*******************************************************************************
;
;Inicialization procedure "Reset and PreSence Pulses"
;
;	480us<=t(RSTL)< . t(RSTL)+t(R)<960us
;	480us<=t(RSTH)<
;	15us <=t(PDH)  <=60us
;	60us <=t(PDL)  <=240us
;
;	 C-flag 	= 1 DS1990A a buszon van
;			= 0 DS1990A nincs a buszon
;
;
;                                    
TouchReset:
;
	SBI	DS1wire_DIR,DS1wire		; 1-wire = Master LOW , Start the reset pulse
	ldi	YL,low((480*SYSCLK)/(1000*4))
	ldi	YH,high((480*SYSCLK)/(1000*4))	; loop cycle = 4
;
TR0:	sbiw	YL,1				; [2]
	brne	TR0  				; [1/2] 480us wait with data low
;
	SBI	DS1wire_PORT,DS1wire		; [2]   1-wire =Active Hi
	NOP					; [1]
	NOP
;	NOP	;?
;	NOP	;?
;
	CBI	DS1wire_DIR,DS1wire		; [2]   1-wire HI (felengedve)
	CBI	DS1wire_PORT,DS1wire		; [2]   1-wire = Tri-state
	NOP					; [1]
	NOP
;	NOP	;?
;	NOP	;?
;
	SBIS	DS1wire_PIN,DS1wire		; [1/2]
	RJMP	Short				; [2]    ha egybol Low az rossz
;
	ldi	YL,low((60*SYSCLK)/(1000*6))
	ldi	YH,high((60*SYSCLK)/(1000*6))	; loop cycle = 6
TR1:	SBIS	DS1wire_PIN,DS1wire		; [1/2]
	RJMP	WL				; [2]    Exit loop if line low
	sbiw	YL,1 				; [2]
	BRNE	TR1  				; [1/2] 60 us wait with data low
	RJMP	SHORT				; [2]   Line could not go low
;
WL:
	ldi	YL,low((240*SYSCLK)/(1000*6))
	ldi	YH,high((240*SYSCLK)/(1000*6))	; loop cycle = 6
TR3:	SBIC	DS1wire_PIN,DS1wire		; [1/2]
	RJMP	WH				; [2]    Exit loop if line hi
	sbiw	YL,1 				; [2]
	BRNE	TR3  				; [1/2] us wait with data low
;
SHORT:	CLC					; [1] Error
	RET					; [4]
;
WH:
	ldi	YL,low((480*SYSCLK)/(1000*4))
	ldi	YH,high((480*SYSCLK)/(1000*4))
TR4:	sbiw	YL,1 				; [2]
	BRNE	TR4  				; [1/2] us wait with data low
;
	SEC					; [1] RESET OK.
	RET					; [4]
;
;****************************************************************************
;******* TOUCHBYTE
;****************************************************************************
;R0-ban megadott byte-ot kikuldi a touchmemory-nak
;es szimultan beolvas egy byte-ot onnan az R1-be
;Hasznalja a R17, R2, R1, R0:
;
                                    
TouchByte:
	LDI	R17,8             		; [1]
BIT_LOOP:
	ROR	R1				; [1]
	RCALL	TOUCHBIT			; [3]
	ROR	R0				; [1]
	DEC	R17				; [1]
	BRNE	BIT_LOOP			; [1/2]
	RET					; [1]
;
TOUCHBIT:
	sbi	DS1wire_DIR,DS1wire		; [2] Start Window line = L, 1us <= Tlowr <= 15us
	ldi	YL,low((2*SYSCLK)/(1000*4))  	; [1] 2us
	ldi	YH,high((2*SYSCLK)/(1000*4)) 	; [1] loop cycle = 4
BW0:	sbiw	YL,1 				; [2]
	BRNE	BW0  				; [1/2] eddig
;
	SBRC	R0,0				; [1/2]
	CBI	DS1wire_DIR,DS1wire		; [2]
;
	ldi	YL,low((13*SYSCLK)/(1000*4))  	; [1] 13us
	ldi	YH,high((13*SYSCLK)/(1000*4)) 	; [1] loop cycle = 4
BW1:	sbiw	YL,1				; [2]
	BRNE	BW1  				; [1/2]
;
	IN	R2,DS1wire_PIN			; [1]
	BST	R2,DS1wire			; [1]
	BLD	R1,7				; [1]
;
	ldi	YL,low((45*SYSCLK)/(1000*4)) 	; [1] 45us
	ldi	YH,high((45*SYSCLK)/(1000*4))	; [1] loop cycle = 4
TCHL:	sbiw	YL,1				; [2]
	BRNE	TCHL				; [1/2]
	CBI	DS1wire_DIR,DS1wire		; [2]
	RET					; [4]
;
;***********************************************************************
;.......................................................................
; Read ROM
; In:  X = address
; Out:
; c=1    DS1990A.
; R1 input byte cikle
;
; USE: Reg_r19, Reg_r16, R1, R0;
;.......................................................................
;
;
Read_Key_DS:
;
	PUSH	R0
	PUSH	R1
	PUSH	R3
	PUSH	R17
	PUSH	R18
	PUSH	Reg_r16
	PUSH	Reg_r19
	PUSH	Reg_r20
	PUSH	temp_1
	PUSH	XL
	PUSH	XH
	PUSH	YL
	PUSH	YH
;

	Cbr	Flag_R,0b0000.0001
	STS	(Var_Flag_R),Flag_R
;
	CLI
;
	LDI	XL,LOW(DSRD)
	LDI	XH,HIGH(DSRD)			; ide olvassa DS Chipet
                                    
	clr	Reg_r16
	sts	CRC,Reg_r16			; CRC=0
	rcall	TouchReset
	BRCS	RDS1				; ESZKOZ A BUSZON VAN
	CLC
	RJMP	Lal_end
                                    
RDS1:
	LDI	Reg_r16,DSReadROM		; SEARCH ROM COMMAND h33
	MOV	R0,Reg_r16
	LDI	Reg_r19,7			; 7-SZER OLVASUNK BE
	RCALL	TouchByte
RDS2:
	LDI	Reg_r16,0xFF			; BEOLVASUNK 8 BITET
	MOV	R0,Reg_r16
	RCALL	TouchByte
	ST	X+,R1
	RCALL	CRCGEN
	DEC	Reg_r19
	BRNE	RDS2
	LDI	Reg_r16,0xFF			; BEOLVASSUK A CRC-t
	MOV	R0,Reg_r16
	RCALL	TouchByte
	ST	X+,R1
;
	ldi	YL,low((480*SYSCLK)/4000)
	ldi	YH,high((480*SYSCLK)/4000)
RDS3:
	sbiw	YL,1
	brne	RDS3
;
	lds	R0,DSRD+7
	lds	temp_1,CRC			; R1,CRC
	cp	R0,temp_1
	brne	CRC_no
;
	cpi	temp_1,0
	breq	CRC_no
;
	cpi	temp_1,0xFF
	breq	CRC_no
;
;||||||||||||||||||||||||||||||||||||||||||||||||
;
	LDS	Reg_r19,(DSRD+0)
	LDS	Reg_r20,(Compare_Read_DS+0)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+1)
	LDS	Reg_r20,(Compare_Read_DS+1)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+2)
	LDS	Reg_r20,(Compare_Read_DS+2)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+3)
	LDS	Reg_r20,(Compare_Read_DS+3)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+4)
	LDS	Reg_r20,(Compare_Read_DS+4)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+5)
	LDS	Reg_r20,(Compare_Read_DS+5)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+6)
	LDS	Reg_r20,(Compare_Read_DS+6)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
	LDS	Reg_r19,(DSRD+7)
	LDS	Reg_r20,(Compare_Read_DS+7)
	CPSE	Reg_r19,Reg_r20
	RJMP	Compare_Code_ERR
;
;
;||||||||||||||||||||||||||||||||||||||||||||||||
	SEC					;    8 , CRC .
;================================================
	Sbr	Flag_R,0b0000.0001		;!!! 0  -    .
	STS	(Var_Flag_R),Flag_R
;
	RJMP	Mode_Rec_Code_Key		;
;================================================
;
CRC_no:	RJMP	CRC_END
;
Compare_Code_ERR:
;
	LDS	Reg_r19,(DSRD+0)
	STS	(Compare_Read_DS+0),Reg_r19
;
	LDS	Reg_r19,(DSRD+1)
	STS	(Compare_Read_DS+1),Reg_r19
;
	LDS	Reg_r19,(DSRD+2)
	STS	(Compare_Read_DS+2),Reg_r19
;
	LDS	Reg_r19,(DSRD+3)
	STS	(Compare_Read_DS+3),Reg_r19
;
	LDS	Reg_r19,(DSRD+4)
	STS	(Compare_Read_DS+4),Reg_r19
;
	LDS	Reg_r19,(DSRD+5)
	STS	(Compare_Read_DS+5),Reg_r19
;
	LDS	Reg_r19,(DSRD+6)
	STS	(Compare_Read_DS+6),Reg_r19
;
	LDS	Reg_r19,(DSRD+7)
	STS	(Compare_Read_DS+7),Reg_r19
;
;===============================================
;
CRC_END:
;
	CLC
;
	Cbr	Flag_R,0b0000.0001		;
	STS	(Var_Flag_R),Flag_R
;
Lal_end:
;
	SEI
;
	POP	YH
	POP	YL
	POP	XH
	POP	XL
	POP	temp_1
	POP	Reg_r20
	POP	Reg_r19
	POP	Reg_r16
	POP	R18	
	POP	R17
	POP	R3
	POP	R1
	POP	R0
;
	RET
;
;\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
;
Mode_Rec_Code_Key:
;
	LDS	Reg_r19,(DSRD+4)
	STS	(ee_paket_byte1),Reg_r19
;
	LDS	Reg_r19,(DSRD+3)
	STS	(ee_paket_byte2),Reg_r19
;
	LDS	Reg_r19,(DSRD+2)
	STS	(ee_paket_byte3),Reg_r19
;
	LDS	Reg_r19,(DSRD+1)
	STS	(ee_paket_byte4),Reg_r19
;
	RJMP	Lal_end
;                                    
;*************************************************************************
;.........................................................................
; DS1990A CRC GENERATOR
; IN: R1
; USE: Reg_r20, R18, R3, R1
;.........................................................................
;

CRCGEN:
	PUSH	R1
	PUSH	R3
	PUSH	R18
	PUSH	Reg_r20
;
	LDI	Reg_r20,8
	LDI	R18,0x18
	PUSH	R1
                                    
CRC_L:
	lds	R3,(CRC)	; CRC  RAM
	EOR	R1,R3
	ROR	R1
	MOV	R1,R3
	BRCC	ZERO
	EOR	R1,R18
ZERO:
	ROR	R1
	sts	CRC,R1
	POP	R1
	SEC
	SBRS	R1,0
	CLC
	ROR	R1
	PUSH	R1
	DEC	Reg_r20
	BRNE	CRC_L
	POP	R1
;
	POP	Reg_r20
	POP	R18
	POP	R3                                    
	POP	R1
;
	RET
;
;=================================================================================

